@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2019  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -15,14 +15,12 @@
 # You should have received a copy of the GNU General Public License
 # along with mrgsolve.  If not, see <http://www.gnu.org/licenses/>.
 
-
 includes <- new.env()
 plugins <- new.env()
 plugins[[".depends"]] <- list(mrgx=c("Rcpp"))
 
 include_order <- c("RcppArmadillo", "Rcpp","BH", "mrgx")
 
-
 get_plugins <- function(what) {
   what <- c(cvec_cs(what), "base")
   what <- unique(c(get_depends(what),what))
@@ -46,7 +44,6 @@ get_plugin <- function(what) {
   plugins[[what]]
 }
 
-
 plugin_code <- function(x) {
   if(is.null(x)) return(NULL)
   s_pick(x,"code") 
@@ -58,7 +55,6 @@ plugin_names <- function(x) {
   paste0("// PLUGINS: ", paste(x, collapse=" "))
 }
 
-
 make_clink <- function(x,clink) {
   if(is.null(x)) return(NULL)
   link <- unique(s_pick(x,"linkto"))
@@ -76,7 +72,6 @@ set_clink <- function(x,clink=NULL) {
   Sys.setenv(CLINK_CPPFLAGS = make_clink(x,clink)) 
 }
 
-
 make_libs <- function(x) {
   if(is.null(x)) return(NULL)
   libs <- unique(s_pick(x,"libs"))
@@ -112,16 +107,10 @@ do_restore <- function(restore) {
   if(any(unset))   Sys.unsetenv(names(restore[unset]))
 }
 
-
 plugins[["base"]] <- list(
   linkto="mrgsolve/base", name="base"
 )
 
-# plugins[["simeta"]] <- list(
-#   linkto="mrgsolve/mrgx",
-#   code='#include "simeta.h"\n',name="simeta"
-# )
-
 plugins[["mrgx"]] <- list(
   linkto="mrgsolve/mrgx",
   code='#include "mrgx.h"\n',name="mrgx"
@@ -148,6 +137,22 @@ plugins[["BH"]] <- list(
   linkto="BH/include", name="BH"
 )
 
+plugins[["TAD"]] <- list(
+  name = "TAD",
+  code = "#define __MRGSOLVE_USE_PLUGIN_TAD__"
+)
+
+read_lines_from_base <- function(file) {
+  readLines(mrgsolve_file("base", file))
+}
+
+
+# 
+# plugins[["REPORT"]] <- list(
+#   name = "REPORT", 
+#   code = c("#define __MRGSOLVE_USE_PLUGIN_REPORT__", '#include "mrgsolve_plugin_report.h"')
+# )
+
 # @param x the build object
 # 
 # @details
@@ -160,15 +165,16 @@ write_build_env <- function(x) {
   clink <- paste0("PKG_CPPFLAGS=",paste(Sys.getenv("CLINK_CPPFLAGS"), collapse=" "))
   libs <- paste0("PKG_LIBS=",paste(Sys.getenv("PKG_LIBS"),collapse=" "))
   
-  
   cat(file=mkv, "# from write_make_vars", "\n")
   cat(file=mkv, clink, "\n", append=TRUE)
   cat(file=mkv, libs,  "\n", append=TRUE)
   
-  headers <- file.path(system.file("base",package="mrgsolve"),c("modelheader.h", "mrgsolv.h"))
+  headers <- file.path(
+    system.file("base",package="mrgsolve"),
+    c("modelheader.h", "mrgsolv.h")
+  )
   
   if(!all(file.copy(headers, x$soloc, overwrite=TRUE))) {
-    stop("Couldn't find mrgsolve install location.") 
+    stop("Couldn't find mrgsolve install location.", call.=FALSE) 
   }
-
 }
