@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2019  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -16,8 +16,10 @@
 # along with mrgsolve.  If not, see <http://www.gnu.org/licenses/>.
 
 
-##' Internal model library.
+##' Internal model library
 ##' 
+##' @param model \code{character} name of a model in the library
+##' @param ... passed to \code{\link{mread_cache}}
 ##' @param list list available models
 ##' @export
 ##' 
@@ -26,6 +28,9 @@
 ##' \code{\link{modlib_pkpd}}, 
 ##' \code{\link{modlib_tmdd}}, \code{\link{modlib_viral}} for details.
 ##' 
+##' Call \code{modlib("<modelname>")} to compile and load a mode from the 
+##' library.
+##' 
 ##' Call \code{modlib(list=TRUE)} to list available models.  Once the model 
 ##' is loaded (see examples below), call \code{as.list(mod)$code} to see
 ##' model code and equations.
@@ -48,18 +53,25 @@
 ##' mod <- mread("tmdd",   modlib())
 ##' mod <- mread("viral1", modlib())
 ##' mod <- mread("viral2", modlib())
+##' mod <- mread("pred1",  modlib())
+##' mod <- mread("pbpk",   modlib())
 ##' 
 ##' mrgsolve:::code(mod)
 ##' }
 ##' 
-modlib <- function(list=FALSE)  {
-  if(list) return(modlib_list())
-  return(object_dir() )
+modlib <- function(model = NULL,...,list=FALSE)  {
+  if(list) {
+    return(modlib_list())
+  }
+  if(is.character(model)) {
+    return(mread_cache(model, project = modlib(), ...))
+  }
+  return(object_dir())
 }
 
 modlib_models <- c("pk1cmt", "pk2cmt", "pk3cmt",
-                   "pk1", "pk2", "popex",
-                   "irm1", "irm2", "irm3",
+                   "pk", "pk1", "pk2", "popex",
+                   "irm1", "irm2", "irm3", "pred1", 
                    "emax", "tmdd", "viral1", "viral2", "effect")
 
 modlib_list <- function() {
@@ -75,7 +87,7 @@ modlib_list <- function() {
 ##'
 ##' @section Compartments:
 ##' \itemize{
-##' \item{\code{EV1}, \code{EV2}}: extravasular dosing compartments
+##' \item{\code{EV1}, \code{EV2}}: extravascular dosing compartments
 ##' \item{\code{CENT}}: central PK compartment
 ##' \item{\code{PERIPH}}: peripheral PK compartment
 ##' \item{\code{PERIPH2}}: peripheral PK compartment 2
@@ -179,7 +191,7 @@ NULL
 ##' parameters and compartments.
 ##'
 ##' All PK/PD models include 2-compartment PK model with absorption from 
-##' 2 extravasular compartments and linear + nonlinear clearance.  The 
+##' 2 extravascular compartments and linear + nonlinear clearance.  The 
 ##' PK models are parameterized with \code{CL}, \code{VC}, \code{Q}, 
 ##' \code{VMAX}, \code{KM}, \code{KA1} and \code{KA2} and implement 
 ##' compartments \code{EV1}, \code{EV2}, \code{CENT}, \code{PERIPH} .  
@@ -219,7 +231,7 @@ NULL
 ##' \item{\code{KINT}}: internalization rate constant
 ##' \item{\code{KON}}: association rate constant
 ##' \item{\code{KOFF}}: dissociation rate constant
-##' \item{\code{KSYN}}: target systhesis rate
+##' \item{\code{KSYN}}: target synthesis rate
 ##' \item{\code{KDEG}}: target degredation rate constant
 ##' }
 ##'
