@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2019  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -24,9 +24,15 @@ options("mrgsolve_mread_quiet"=TRUE)
 
 context("test-ev")
 
-test_that("event requirements and defaults", {
-  expect_error(ev(time=24))
+test_that("observations are not allowed", {
   expect_error(ev(amt=100, evid=0))
+})
+
+test_that("doses are required", {
+  expect_error(ev(time=24), "amt")
+})
+
+test_that("event requirements and defaults", {
   expect_is(ev(amt=100), "ev")
   df <- as.data.frame(ev(amt=100))
   expect_equal(df$time, 0)
@@ -52,7 +58,7 @@ test_that("realized events", {
   expect_true(all(e$amt==100))
   expect_true(all(e$ii==0))
   expect_true(all(e$addl==0))
-  
+
   e1 <- ev(amt=100, ii=24, addl=1)
   e2 <- ev(amt=200, ii=24, addl=3, time=1)
   e <- as.data.frame(ev(e1+e2,realize_addl=TRUE))
@@ -63,23 +69,22 @@ test_that("realized event error", {
   expect_error(ev(amt=100, addl=24, realize_addl=TRUE))
 })
 
-
 test_that("sequence of event objects", {
-  
+
   e1 <- ev(amt=1, ii=24, addl=3)
   e2 <- ev(amt=2, ii=24, addl=1)
   e3 <- ev(amt=3, ii=12, addl=4)
-  
-  e <- as.data.frame(seq(e1,e2,e3))
+
+  e <- as.data.frame(ev_seq(e1,e2,e3))
   expect_equal(nrow(e), 3)
   expect_equal(e$time, c(0,96, 144))
-  
-  e <- seq(e1, wait = 20, e2, wait= -10, e3)
+
+  e <- ev_seq(e1, wait = 20, e2, wait= -10, e3)
   e <- as.data.frame(e)
   expect_equal(nrow(e), 3)
   expect_equal(e$time, c(0,116,154))
-  expect_is(seq(e2, e1, wait=2, e1),"ev")
-  
+  expect_is(ev_seq(e2, e1, wait=2, e1),"ev")
+
 })
 
 test_that("replicate an event object", {
@@ -92,7 +97,7 @@ test_that("replicate an event object", {
 test_that("events with without rate" , {
   e1 <- ev(amt=1, ii=12)
   e2 <- ev(amt=2, ii=24, rate=1)
-  e <- seq(e1,e2)
+  e <- ev_seq(e1,e2)
   expect_is(e, "ev")
   e <- as.data.frame(e)
   expect_equal(e$rate,c(0,1))
@@ -100,33 +105,35 @@ test_that("events with without rate" , {
 
 test_that("coerce to data frame", {
   e <- ev(amt = 100)
-  
+
   ans <- as.data.frame(e)
   expect_is(ans, "data.frame")
   expect_false(mrgsolve:::has_ID(ans))
-  
+
   ans <- as.data.frame(e, add_ID = 2)
   expect_is(ans, "data.frame")
   expect_true(mrgsolve:::has_ID(ans))
   expect_equal(ans$ID, 2)
-  
+
   e <- ev(amt = 100, ID = 4)
   ans <- as.data.frame(e, add_ID = 2)
   expect_equal(ans$ID, 4)
 })
 
-
 test_that("get names", {
   e <- ev(amt = 100, time = 0, evid = 1, ii = 12, addl = 24)
-  expect_equal(names(e), c("time", "cmt", "amt", "ii", "addl", "evid"))
+  expect_equal(
+    names(e),
+    c("time", "cmt", "amt", "evid", "ii", "addl")
+  )
 })
 
 test_that("mutate an ev object", {
-    e <- ev(amt = 100, cmt = 1)
-    e2 <- mutate(e, cmt = 2)
-    expect_is(e2, "ev")
-    df <- as.data.frame(e2)
-    expect_equal(df$cmt, 2)
+  e <- ev(amt = 100, cmt = 1)
+  e2 <- mutate(e, cmt = 2)
+  expect_is(e2, "ev")
+  df <- as.data.frame(e2)
+  expect_equal(df$cmt, 2)
 })
 
 test_that("filter an ev object", {
@@ -137,28 +144,25 @@ test_that("filter an ev object", {
 })
 
 test_that("misc methods", {
-    e <- ev(amt = 100)
-    expect_true(mrgsolve:::is.ev(e))
-    expect_false(mrgsolve:::is.ev(as.data.frame(e)))
+  e <- ev(amt = 100)
+  expect_true(mrgsolve:::is.ev(e))
+  expect_false(mrgsolve:::is.ev(as.data.frame(e)))
 })
 
 test_that("as.ev", {
-  df <- data_frame(amt = 100, foo = 5)
+  df <- tibble(amt = 100, foo = 5)
   d <- as.data.frame(as.ev(df))
   expect_equal(d$cmt,1)
   expect_equal(d$amt,100)
   expect_equal(d$evid,1)
   expect_equal(d$time,0)
   expect_equal(d$foo,5)
-  
-  df <- data_frame(amt = 200, evid = 1)
+
+  df <- tibble(amt = 200, evid = 1)
   obs <- mutate(df, evid = 0)
   df <- bind_rows(df,obs)
   d <- as.data.frame(as.ev(df))
-  
+
   expect_equal(d$evid,1)
-  
+
 })
-
-
-
